==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebDockManagerResourceStringsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerResourceStringsDescription } from "./WebDockManagerResourceStringsDescription";
/**
 * @hidden
 */
var WebDockManagerResourceStringsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebDockManagerResourceStringsDescriptionMetadata, _super);
    function WebDockManagerResourceStringsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDockManagerResourceStringsDescriptionMetadata.b = function (a) {
        if (WebDockManagerResourceStringsDescriptionMetadata.a == null) {
            WebDockManagerResourceStringsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDockManagerResourceStringsDescriptionMetadata.c(WebDockManagerResourceStringsDescriptionMetadata.a);
        }
        if (a.g(WebDockManagerResourceStringsDescriptionMetadata.a)) {
            return;
        }
        a.s(WebDockManagerResourceStringsDescriptionMetadata.a);
    };
    WebDockManagerResourceStringsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DockManagerResourceStrings");
        a.item("Close", "String");
        a.item("Pin", "String");
        a.item("Unpin", "String");
        a.item("Maximize", "String");
        a.item("Minimize", "String");
        a.item("MoreOptions", "String");
        a.item("MoreTabs", "String");
        a.item("Panes", "String");
        a.item("Documents", "String");
    };
    WebDockManagerResourceStringsDescriptionMetadata.d = function (a) {
        WebDockManagerResourceStringsDescriptionMetadata.b(a);
        a.u("WebDockManagerResourceStrings", function () { return new WebDockManagerResourceStringsDescription(); });
        a.t("WebDockManagerResourceStrings", WebDockManagerResourceStringsDescriptionMetadata.a);
    };
    WebDockManagerResourceStringsDescriptionMetadata.$t = markType(WebDockManagerResourceStringsDescriptionMetadata, 'WebDockManagerResourceStringsDescriptionMetadata');
    WebDockManagerResourceStringsDescriptionMetadata.a = null;
    return WebDockManagerResourceStringsDescriptionMetadata;
}(Base));
export { WebDockManagerResourceStringsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebDockManagerResourceStringsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerResourceStringsDescription } from "./WebDockManagerResourceStringsDescription";
/**
 * @hidden
 */
var WebDockManagerResourceStringsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebDockManagerResourceStringsDescriptionMetadata, _super);
    function WebDockManagerResourceStringsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDockManagerResourceStringsDescriptionMetadata.b = function (a) {
        if (WebDockManagerResourceStringsDescriptionMetadata.a == null) {
            WebDockManagerResourceStringsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDockManagerResourceStringsDescriptionMetadata.c(WebDockManagerResourceStringsDescriptionMetadata.a);
        }
        if (a.j(WebDockManagerResourceStringsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebDockManagerResourceStringsDescriptionMetadata.a);
    };
    WebDockManagerResourceStringsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DockManagerResourceStrings");
        a.item("Close", "String");
        a.item("Pin", "String");
        a.item("Unpin", "String");
        a.item("Maximize", "String");
        a.item("Minimize", "String");
        a.item("MoreOptions", "String");
        a.item("MoreTabs", "String");
        a.item("Panes", "String");
        a.item("Documents", "String");
    };
    WebDockManagerResourceStringsDescriptionMetadata.d = function (a) {
        WebDockManagerResourceStringsDescriptionMetadata.b(a);
        a.aa("WebDockManagerResourceStrings", function () { return new WebDockManagerResourceStringsDescription(); });
        a.z("WebDockManagerResourceStrings", WebDockManagerResourceStringsDescriptionMetadata.a);
    };
    WebDockManagerResourceStringsDescriptionMetadata.$t = markType(WebDockManagerResourceStringsDescriptionMetadata, 'WebDockManagerResourceStringsDescriptionMetadata');
    WebDockManagerResourceStringsDescriptionMetadata.a = null;
    return WebDockManagerResourceStringsDescriptionMetadata;
}(Base));
export { WebDockManagerResourceStringsDescriptionMetadata };
